# Changelog

# 0.2.2 - 2024-11-04

- bugfix - clone was looking for a git folder, instead of a .git folder
- redo botched release (0.2.1 never made it to pypi)

# 0.2.0 - 2024-10-29

- support for ssh urls

## 0.1.4 - 2024-10-14

- extra arguments to the diff command are passed to git diff as-is

## 0.1.3 - 2024-10-14

- add a help message to all commands
- new summary --quiet option

## 0.1.2 - 2024-10-13

- first public release
